#!/usr/bin/perl

use strict;
use warnings;

use Pod::Usage;

# configure Getopt::Long to parse argument string in GNU style
use Getopt::Long qw(:config gnu_getopt);

my @files;
my $verbose;

#BEGIN {
   # Gimp module insists on parsing @ARGV on its own; for this reason
   # argument string is parsed here

   my %options;

   GetOptions(\%options, 'help|?', 'verbose|v+', 'man');
   pod2usage(-exitval => 0,
             -verbose => 2,
             -output  => \*STDOUT) if $options{man};
   pod2usage(-exitval => 0,
             -output  => \*STDOUT) if $options{help};
   @files = @ARGV;
   pod2usage(2) unless @files;

   $verbose = $options{verbose} || 0;
#}


eval {
	require Gimp;
	require Gimp::Fu;
};

if ($@) {
	warn "Unable to load Gimp module. Make sure you have Gtk-Perl installed\n";
	exit 1;
}
import Gimp qw( :auto );

# init Gimp modules
Gimp::set_trace(TRACE_ALL) if $verbose > 1;
Gimp::init;

for my $file (@files) {
   print "Loading $file...\n" if $verbose > 0;
   my $img = eval { Gimp->file_psd_load($file, $file) };

   if($@) {
       # catch file loading errors and skip to the next file
       warn $@;
       next;
   }

   print "Applying effect ...\n" if $verbose > 0;


my $layer = $img->layer_new($img->width, $img->height,
                  RGBA_IMAGE,
                  "first layer",
                  100, NORMAL_MODE);
    $img->add_layer($layer, 0);
    
       my $drawable = $img->merge_visible_layers(0);
  
    
   print "Saving $file ...\n" if $verbose > 0;
   my $quality     = 1.0;
   my $smoothing   = 0;
   my $optimize    = 1;
   my $progressive = 0;
   my $comment     = 'polom';
   my $subsmp      = 0;
   my $baseline    = 1;
   my $restart     = 0;
   my $dst         = 2;
   eval {
#Gimp::set_trace(-1);
       Gimp->file_png_save($img, $drawable, "/tmp/showimgFromPSD.png", "/tmp/showimgFromPSD.png", 0, 0, 0, 0, 0, 0, 0);
#Gimp::set_trace(0);	
   };
   if($@) {
       # catch file saving errors and skip to the next file
       warn $@;
       next;
   }

   # free memory
   $img->delete;
}
